@@ -74,10 +74,12 @@ void mp_obj_print_helper(const mp_print_t *print, mp_obj_t o_in, mp_print_kind_t
     }
 #endif
     mp_obj_type_t *type = mp_obj_get_type(o_in);
-    if (type->print != NULL) {
+    if (type){
+      if (type->print != NULL) {
         type->print((mp_print_t*)print, o_in, kind);
-    } else {
+      } else {
         mp_printf(print, "<%q>", type->name);
+      }
     }
 }
 
