@@ -21,6 +21,10 @@
 #ifndef _GIAC_FIRST_H_
 #define _GIAC_FIRST_H_
 
+#ifdef _GLIBCXX_ASSERTIONS
+#undef _GLIBCXX_ASSERTIONS
+#endif
+
 #ifdef NUMWORKS
 #define KHICAS 1
 #endif
@@ -174,8 +178,8 @@ typedef double giac_double;
 typedef long double  long_double;
 
 // sprintf replacement
-// calls snprintf instead of sprintf with n=256, assumes s bufsize>=256
-int sprintf256(char *s,const char *format,...);
+// calls snprintf instead of sprintf with n=512, assumes s bufsize>=512
+int sprintf512(char *s,const char *format,...);
 int my_sprintf(char * s, const char * format, ...);
 #ifdef GIAC_HAS_STO_38
 //#define WITH_MYOSTREAM
