@@ -255,7 +255,7 @@ namespace giac {
   }
 
 
-#ifdef HAVE_GMPXX_H
+#if defined HAVE_GMPXX_H && !defined BF2GMP_H
   template <class U>
   bool convert_myint(const polynome & p,const index_t & deg,std::vector< T_unsigned<mpz_class,U> >  & v){
     typename std::vector< monomial<gen> >::const_iterator it=p.coord.begin(),itend=p.coord.end();
@@ -536,7 +536,7 @@ namespace giac {
 #endif
     else {
       index_t i(pdim);
-      index_t::iterator iitbeg=i.begin(),iitback=i.end()-1,iitbackm1=iitback-1;
+      index_t::iterator /*iitbeg=i.begin(),*/ iitback=i.end()-1,iitbackm1=iitback-1;
       for (--prevu;it!=itend;++it,++jt){
 	u=it->u;
 	if (prevu<=u+*iitback){
@@ -548,7 +548,7 @@ namespace giac {
 	    --(*iitbackm1);
 	    *iitback += short((u+(*ditbeg))-prevu);
 	    prevu=u;
-	    // cerr << "/" << u << ":" << i << endl;
+	    // cerr << "/" << u << ":" << i << '\n';
 	  }
 	  else 
           {
@@ -571,7 +571,7 @@ namespace giac {
       }
     }
     if (debug_infolevel>5)
-      CERR << "Divisions: " << count << std::endl;
+      CERR << "Divisions: " << count << '\n';
   }
 
   
@@ -592,8 +592,10 @@ namespace giac {
 
   extern int threads;
 
+  // conversion in parallel will not be much faster if T!=gen because
+  // we must allocate memory for each gen
   template<class T,class U>
-  void convert_from(const std::vector< T_unsigned<T,U> > & v,const index_t & deg,polynome & p,bool threaded=false){
+  void convert_from(const std::vector< T_unsigned<T,U> > & v,const index_t & deg,polynome & p,bool threaded=false,bool coeff_apart=false){
     typename std::vector< T_unsigned<T,U> >::const_iterator it=v.begin(),itend=v.end();
     p.dim=int(deg.size());
     // p.coord.clear(); p.coord.reserve(itend-it);
@@ -604,15 +606,20 @@ namespace giac {
       convert_from<T,U>(it,itend,deg,jt,0); 
       return;
     }
-#if defined(HAVE_PTHREAD_H) && !defined(EMCC) // && !defined(__clang__)
+#if defined(HAVE_PTHREAD_H) && !defined(EMCC) && !defined(EMCC2) // && !defined(__clang__)
     unsigned taille=itend-it;
     if (nthreads>1 
 	&& int(taille)>nthreads*1000
 	){
       pthread_t tab[nthreads];
       std::vector< convert_t<T,U> > arg(nthreads);
+      if (coeff_apart){
+	convert_from<T,U>(it,itend,deg,jt,1); // convert first coefficients
+	if (debug_infolevel>5)
+	  CERR << CLOCK()*1e-6 << " end coefficients conversion" << '\n';
+      }
       for (int i=0;i<nthreads;i++){
-	convert_t<T,U> tmp={it+i*(taille/nthreads),it+(i+1)*taille/nthreads,&deg,jt+i*(taille/nthreads),0};
+	convert_t<T,U> tmp={it+i*(taille/nthreads),it+(i+1)*taille/nthreads,&deg,jt+i*(taille/nthreads),coeff_apart?2:0};
 	if (i==nthreads-1){
 	  tmp.itend=itend;
 	  convert_from<T,U>(tmp.it,tmp.itend,deg,tmp.jt,tmp.mode);
@@ -620,7 +627,7 @@ namespace giac {
 	else {
 	  arg[i]=tmp;
 	  int res=pthread_create(&tab[i],(pthread_attr_t *) NULL,do_convert_from<T,U>,(void *) &arg[i]);
-	  if (res)
+	  if (res) // thread not created
 	    convert_from<T,U>(tmp.it,tmp.itend,deg,tmp.jt,tmp.mode);
 	}
       }
