@@ -768,7 +768,7 @@ namespace giac {
       gen & tmp=e._SYMBptr->feuille;
       if (tmp.type==_VECT && tmp._VECTptr->size()==2){
 	gen base=tmp._VECTptr->front(),expo=tmp._VECTptr->back();
-	if (!complex_mode(contextptr) && expo.type==_INT_ && expo.val%2==0)
+	if (!complex_mode(contextptr) && do_lnabs(contextptr) && expo.type==_INT_ && expo.val%2==0)
 	  base=abs(base,contextptr);
 	return expo*ln_expand0(base,contextptr);
       }
@@ -1552,13 +1552,13 @@ namespace giac {
 	if (is_zero(a)){ ok=false; break; }
       }
       if (ok) break;
-      double z=rand()*0.1/RAND_MAX;
+      double z=std_rand()*0.1/RAND_MAX;
       xmin -= z*std::abs(xmin);
-      z=rand()*0.1/RAND_MAX;
+      z=std_rand()*0.1/RAND_MAX;
       xmax += z*std::abs(xmax);
-      z=rand()*0.1/RAND_MAX;
+      z=std_rand()*0.1/RAND_MAX;
       ymin -= z*std::abs(ymin);
-      z=rand()*0.1/RAND_MAX;
+      z=std_rand()*0.1/RAND_MAX;
       ymax += z*std::abs(ymax);      
     }
     vector<double> yxmin,yxmax,xymin,xymax; // contains intersections of curves with the 4 edges of the domain
