@@ -68,6 +68,7 @@ namespace giac {
   extern const unary_function_ptr * const  at_complex ;
 
   gen _tcoeff(const gen & args,GIAC_CONTEXT);
+  vecteur sqrfree(const gen & g,const vecteur & l,int mult,GIAC_CONTEXT);
   gen _sqrfree(const gen & args,GIAC_CONTEXT);
   gen _truncate(const gen & args,GIAC_CONTEXT);
   gen _canonical_form(const gen & args,GIAC_CONTEXT);
@@ -82,6 +83,7 @@ namespace giac {
   gen _gramschmidt(const gen & g,GIAC_CONTEXT);
   gen _fmod(const gen & g,GIAC_CONTEXT);
   gen _pmin(const gen & g,GIAC_CONTEXT);
+  bool is_potential(const vecteur & fv,const vecteur & xv,gen & res,GIAC_CONTEXT);
   gen _potential(const gen & g,GIAC_CONTEXT);
   gen _vpotential(const gen & g,GIAC_CONTEXT);
   gen _poly2symb(const gen & g,GIAC_CONTEXT);
