@@ -265,6 +265,7 @@
  & at_adjoint_matrix,
  & at_display,
  & at_affix,
+ & at_area,
  & at_alg,
  & at_algsubs,
  & at_algvar,
@@ -321,6 +322,7 @@
  & at_bar_plot,
  & at_barplot,
  & at_barycenter,
+ & at_barycenter,
  & at_basis,
  & at_batons,
  & at_bernoulli,
@@ -338,6 +340,7 @@
  & at_binomial_icdf,
  & at_binprint,
  & at_bisector,
+ & at_bisector,
  & at_bitand,
  & at_bitmap,
  & at_bitor,
@@ -402,6 +405,7 @@
  & at_chrem,
  & at_circle,
  & at_circumcircle,
+ & at_circumcircle,
  & at_classes,
  & at_clear,
  & at_clearscreen,
@@ -433,6 +437,7 @@
  & at_cone,
  & at_confidence,
  & at_conic,
+ & at_conic,
  & at_conj,
  & at_conjugate_gradient,
  & at_cont,
@@ -533,6 +538,7 @@
  & at_divmod,
  & at_divpc,
  & at_dodecahedron,
+ & at_dodecahedron,
  & at_domain,
  & at_dot,
  & at_dotP,
@@ -699,6 +705,7 @@
  & at_getType,
  & at_getKey,
  & at_get_pixel,
+ & at_getKey,
  & at_ggb_ang,
  & at_ggbalt,
  & at_ggbsort,
@@ -728,6 +735,7 @@
  & at_harmonic_division,
  & at_has,
  & at_hasard,
+ & at_altitude,
  & at_head,
  & at_heading,
  & at_heap_mult,
@@ -747,10 +755,12 @@
  & at_histogram,
  & at_hold,
  & at_homothety,
+ & at_homothety,
  & at_horner,
  & at_hp38,
  & at_hyp2exp,
  & at_hyperbola,
+ & at_hyperbola,
  & at_hyperplan,
  & at_hypersphere,
  & at_hypersurface,
@@ -764,6 +774,7 @@
  & at_ichrem,
  & at_icontent,
  & at_icosahedron,
+ & at_icosahedron,
  & at_id,
  & at_identity,
  & at_idivis,
@@ -794,6 +805,7 @@
  & at_innertln,
  & at_input,
  & at_inputform,
+ & at_incircle,
  & at_insert,
  & at_insmod,
  & at_int,
@@ -802,6 +814,7 @@
  & at_integrate,
  & at_integrer,
  & at_inter,
+ & at_single_inter,
  & at_interactive,
  & at_interactive_odeplot,
  & at_interactive_plotode,
@@ -960,10 +973,13 @@
  & at_mean,
  & at_median,
  & at_median_line,
+ & at_median_line,
+ & at_perpen_bisector,
  & at_member,
  & at_mgf,
  & at_mid,
  & at_midpoint,
+ & at_midpoint,
  & at_min,
  & at_min_proba_time,
  & at_mkdir,
@@ -1024,6 +1040,7 @@
  & at_nullspace,
  & at_numer,
  & at_octahedron,
+ & at_octahedron,
  & at_octprint,
  & at_odd,
  & at_odeplot,
@@ -1048,6 +1065,7 @@
  & at_pade,
  & at_padic_linsolve,
  & at_parabola,
+ & at_parabola,
  & at_parabolic_interpolate,
  & at_parallel,
  & at_parallelepiped,
@@ -1085,6 +1103,7 @@
  & at_pixoff,
  & at_pixon,
  & at_plane,
+ & at_plane,
  & at_plot,
  & at_plot3d,
  & at_plot_style,
@@ -1121,6 +1140,7 @@
  & at_polyEval,
  & at_polygamma,
  & at_polygon,
+ & at_polygone,
  & at_polygone_rempli,
  & at_polygonplot,
  & at_polygonscatterplot,
@@ -1326,6 +1346,7 @@
  & at_signature,
  & at_signe,
  & at_similarity,
+ & at_similarity,
  & at_simp2,
  & at_simplex_reduce,
  & at_simplifier,
@@ -1359,6 +1380,7 @@
  & at_solve_zero_extremum,
  & at_somme,
  & at_sommet,
+ & at_vertices,   
  & at_sort,
  & at_sorta,
  & at_sortd,
@@ -1439,6 +1461,7 @@
  & at_testfunc,
  & at_tests,
  & at_tetrahedron,
+ & at_tetrahedron,
  & at_texpand,
  & at_textinput,
  & at_threads_allowed,
@@ -1448,6 +1471,7 @@
  & at_total_degree,
  & at_tourne_droite,
  & at_tourne_gauche,
+ & at_towards,
  & at_trace,
  & at_tran,
  & at_translation,
@@ -1485,12 +1509,14 @@
  & at_vandermonde,
  & at_variance,
  & at_vector,
+ & at_vector,
  & at_vers,
  & at_version,
  & at_vertices,
  & at_vertices_abc,
  & at_vertices_abca,
  & at_speed,
+ & at_volume,
  & at_vpotential,
  & at_warn_equal_in_prog,
  & at_watch,
